==> mahara_1.4.2.orig.tar.gz: mahara-1.4.2/htdocs/export/html/lang/en.utf8/export.html.php <==
<?php
/**
 * Mahara: Electronic portfolio, weblog, resume builder and social networking
 * Copyright (C) 2006-2009 Catalyst IT Ltd and others; see:
 *                         http://wiki.mahara.org/Contributors
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * @package    mahara
 * @subpackage export.html
 * @author     Catalyst IT Ltd
 * @license    http://www.gnu.org/copyleft/gpl.html GNU GPL
 * @copyright  (C) 2006-2009 Catalyst IT Ltd http://catalyst.net.nz
 *
 */

defined('INTERNAL') || die();

$string['title'] = 'Standalone HTML Website';
$string['description'] = 'Creates a self-contained website with your portfolio data. You cannot import this again, but it\'s readable in a standard web browser.';
$string['usersportfolio'] = '%s - Portfolio';

$string['preparing'] = 'Preparing %s';
$string['exportingdatafor'] = 'Exporting data for %s';
$string['buildingindexpage'] = 'Building index page';
$string['copyingextrafiles'] = 'Copying extra files';

==> mahara_1.5.1.orig.tar.gz: mahara-1.5.1/htdocs/export/html/lang/en.utf8/export.html.php <==
<?php
/**
 * Mahara: Electronic portfolio, weblog, resume builder and social networking
 * Copyright (C) 2006-2009 Catalyst IT Ltd and others; see:
 *                         http://wiki.mahara.org/Contributors
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * @package    mahara
 * @subpackage export.html
 * @author     Catalyst IT Ltd
 * @license    http://www.gnu.org/copyleft/gpl.html GNU GPL
 * @copyright  (C) 2006-2009 Catalyst IT Ltd http://catalyst.net.nz
 *
 */

defined('INTERNAL') || die();

$string['title'] = 'Standalone HTML web site';
$string['description'] = 'Creates a self-contained web site with your portfolio data. You cannot import this again, but it\'s readable in a standard web browser.';
$string['usersportfolio'] = '%s - Portfolio';

$string['preparing'] = 'Preparing %s';
$string['exportingdatafor'] = 'Exporting data for %s';
$string['buildingindexpage'] = 'Building index page';
$string['copyingextrafiles'] = 'Copying extra files';
